==> causeway-bom-2.1.0-source-release.zip: causeway-bom-2.1.0/persistence/jpa/metamodel/src/main/java/org/apache/causeway/persistence/jpa/metamodel/facets/prop/column/MaxLengthFacetFromJpaColumnAnnotation.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.persistence.jpa.metamodel.facets.prop.column;

import java.util.Optional;

import javax.persistence.Column;

import org.apache.causeway.core.metamodel.facetapi.FacetHolder;
import org.apache.causeway.core.metamodel.facets.objectvalue.maxlen.MaxLengthFacet;
import org.apache.causeway.core.metamodel.facets.objectvalue.maxlen.MaxLengthFacetAbstract;

public class MaxLengthFacetFromJpaColumnAnnotation
extends MaxLengthFacetAbstract {

    public static Optional<MaxLengthFacet> create(
            final Optional<Column> columnIfAny,
            final FacetHolder holder) {

        return columnIfAny
                .filter(column -> column.length() > 0)
                .map(column->
                    new MaxLengthFacetFromJpaColumnAnnotation(
                            column.length(), holder));
    }

    private MaxLengthFacetFromJpaColumnAnnotation(
            final int maxLength, final FacetHolder holder) {
        super(maxLength, holder);
    }


}

==> causeway-bom-3.0.0-source-release.zip: causeway-bom-3.0.0/persistence/jpa/metamodel/src/main/java/org/apache/causeway/persistence/jpa/metamodel/facets/prop/column/MaxLengthFacetFromJpaColumnAnnotation.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.persistence.jpa.metamodel.facets.prop.column;

import java.util.Optional;

import jakarta.persistence.Column;

import org.apache.causeway.core.metamodel.facetapi.FacetHolder;
import org.apache.causeway.core.metamodel.facets.objectvalue.maxlen.MaxLengthFacet;
import org.apache.causeway.core.metamodel.facets.objectvalue.maxlen.MaxLengthFacetAbstract;

public class MaxLengthFacetFromJpaColumnAnnotation
extends MaxLengthFacetAbstract {

    public static Optional<MaxLengthFacet> create(
            final Optional<Column> columnIfAny,
            final FacetHolder holder) {

        return columnIfAny
                .filter(column -> column.length() > 0)
                .map(column->
                    new MaxLengthFacetFromJpaColumnAnnotation(
                            column.length(), holder));
    }

    private MaxLengthFacetFromJpaColumnAnnotation(
            final int maxLength, final FacetHolder holder) {
        super(maxLength, holder);
    }


}
